==> lightdash_client_python-0.692.1.tar.gz: lightdash_client_python-0.692.1/lightdash_client/api/exploring/run_sql_query.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ... import errors
from ...client import Client
from ...models.run_sql_query_json_body import RunSqlQueryJsonBody
from ...models.run_sql_query_response_200 import RunSqlQueryResponse200
from ...types import Response


def _get_kwargs(
    project_uuid: str,
    *,
    client: Client,
    json_body: RunSqlQueryJsonBody,
) -> Dict[str, Any]:
    url = "{}/api/v1/projects/{projectUuid}/sqlQuery".format(client.base_url, projectUuid=project_uuid)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "follow_redirects": client.follow_redirects,
        "json": json_json_body,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[RunSqlQueryResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RunSqlQueryResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[RunSqlQueryResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_uuid: str,
    *,
    client: Client,
    json_body: RunSqlQueryJsonBody,
) -> Response[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        json_body (RunSqlQueryJsonBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RunSqlQueryResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_uuid: str,
    *,
    client: Client,
    json_body: RunSqlQueryJsonBody,
) -> Optional[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        json_body (RunSqlQueryJsonBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        RunSqlQueryResponse200
    """

    return sync_detailed(
        project_uuid=project_uuid,
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    project_uuid: str,
    *,
    client: Client,
    json_body: RunSqlQueryJsonBody,
) -> Response[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        json_body (RunSqlQueryJsonBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RunSqlQueryResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_uuid: str,
    *,
    client: Client,
    json_body: RunSqlQueryJsonBody,
) -> Optional[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        json_body (RunSqlQueryJsonBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        RunSqlQueryResponse200
    """

    return (
        await asyncio_detailed(
            project_uuid=project_uuid,
            client=client,
            json_body=json_body,
        )
    ).parsed

==> lightdash_client_python-0.1200.0.tar.gz: lightdash_client_python-0.1200.0/lightdash_client/api/exploring/run_sql_query.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.run_sql_query_body import RunSqlQueryBody
from ...models.run_sql_query_response_200 import RunSqlQueryResponse200
from ...types import Response


def _get_kwargs(
    project_uuid: str,
    *,
    body: RunSqlQueryBody,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": f"/api/v1/projects/{project_uuid}/sqlQuery",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[RunSqlQueryResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RunSqlQueryResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[RunSqlQueryResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: RunSqlQueryBody,
) -> Response[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        body (RunSqlQueryBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RunSqlQueryResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: RunSqlQueryBody,
) -> Optional[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        body (RunSqlQueryBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        RunSqlQueryResponse200
    """

    return sync_detailed(
        project_uuid=project_uuid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: RunSqlQueryBody,
) -> Response[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        body (RunSqlQueryBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[RunSqlQueryResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: RunSqlQueryBody,
) -> Optional[RunSqlQueryResponse200]:
    """Run a raw sql query against the project's warehouse connection

    Args:
        project_uuid (str):
        body (RunSqlQueryBody): The query to run

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        RunSqlQueryResponse200
    """

    return (
        await asyncio_detailed(
            project_uuid=project_uuid,
            client=client,
            body=body,
        )
    ).parsed
